@@ -6,11 +6,11 @@ use utf8;
 use warnings;
 
 # Version.
-our $VERSION = 0.20;
+our $VERSION = 0.21;
 
 # Modules.
 use Acme::CPANAuthors::Register(
-	'CHOROBA' => 'E. Choroba',
+	'CHOROBA' => 'Egon Choroba',
 	'DANIELR' => 'Roman Daniel',
 	'DANPEDER' => 'Daniel Peder',
 	'DOUGLISH' => 'Dalibor Hořínek',
@@ -171,11 +171,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2011-2015 Michal Špaček
+ © 2011-2016 Michal Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.20
+0.21
 
 =cut
